pub fn log(cx: &mut App, level: LogLevel, message: impl Into<SharedString>)Expand description
Append a log line, stamped with the source location it was called from.
pub fn log(cx: &mut App, level: LogLevel, message: impl Into<SharedString>)Append a log line, stamped with the source location it was called from.