with_tree

Function with_tree 

pub fn with_tree<R>(f: impl FnOnce(&ProbeTree) -> R) -> R
Run f against the current tree without cloning it — for a host that wants to inspect the tree without paying for a copy of it.